@@ -7,10 +7,11 @@
 #include "go-combo-text.h"
 #include "go-combo-box.h"
 #include <goffice/utils/go-marshalers.h>
+#include <goffice/gtk/go-gtk-compat.h>
 
 #include <gsf/gsf-impl-utils.h>
 
-struct _GoComboText {
+struct _GOComboText {
 	GOComboBox parent;
 
 	GCompareFunc cmp_func;
@@ -110,8 +111,9 @@ static void
 cb_scroll_size_request (GtkWidget *widget, GtkRequisition *requisition,
 			GOComboText *ct)
 {
-	GtkRequisition list_req;
-	int mon_width, mon_height;
+	GtkRequisition list_req, w_req;
+	GtkAllocation allocation;
+	int mon_width, mon_height, border_width;
 	GdkRectangle rect;
 	GdkScreen    *screen;
 
@@ -125,6 +127,7 @@ cb_scroll_size_request (GtkWidget *widget, GtkRequisition *requisition,
 	gdk_screen_get_monitor_geometry (screen, 0, &rect);
 	mon_width  = rect.width;
 	mon_height = rect.height;
+	border_width = gtk_container_get_border_width (GTK_CONTAINER (widget));
 
 	gtk_widget_size_request	(ct->list, &list_req);
 	if (requisition->height < list_req.height) {
@@ -135,11 +138,12 @@ cb_scroll_size_request (GtkWidget *widget, GtkRequisition *requisition,
 			/* Make room for a whole number of items which don't
 			 * overflow the screen, but no more than 20. */
 			int avail_height, nitems;
-			
+
+			gtk_widget_get_child_requisition (GTK_WIDGET (w), &w_req);
 			avail_height = mon_height - 20
-				- GTK_CONTAINER (widget)->border_width * 2 + 4;
-			nitems = MIN (20, avail_height * ct->rows / w->requisition.height);
-			height = nitems *  w->requisition.height / ct->rows;
+				- border_width * 2 + 4;
+			nitems = MIN (20, avail_height * ct->rows / w_req.height);
+			height = nitems *  w_req.height / ct->rows;
 			if (height > list_req.height)
 				height = list_req.height;
 		}
@@ -148,12 +152,12 @@ cb_scroll_size_request (GtkWidget *widget, GtkRequisition *requisition,
 		 * without it things end up scrolling.
 		 */
 		requisition->height = height +
-			GTK_CONTAINER (widget)->border_width * 2 + 4;
+			border_width * 2 + 4;
 	}
 
-	requisition->width  = MAX (requisition->width, 
-				   ct->entry->allocation.width + 
-				   GTK_CONTAINER (widget)->border_width * 2);
+	gtk_widget_get_allocation (ct->entry, &allocation);
+	requisition->width  = MAX (requisition->width,
+				   allocation.width + border_width * 2);
 	requisition->width  = MIN (requisition->width, mon_width - 20);
 	requisition->height = MIN (requisition->height, mon_height - 20);
 }
@@ -169,7 +173,7 @@ cb_screen_changed (GOComboText *ct, GdkScreen *previous_screen)
 	if (screen) {
 		GtkWidget *toplevel = gtk_widget_get_toplevel (ct->scroll);
 		gtk_window_set_screen (GTK_WINDOW (toplevel), screen);
-	}	
+	}
 }
 
 static void
